summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/cellfrm.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/cellfrm.hxx')
-rw-r--r--sw/source/core/inc/cellfrm.hxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/sw/source/core/inc/cellfrm.hxx b/sw/source/core/inc/cellfrm.hxx
index a6d4dc975525..d33ea5582c8e 100644
--- a/sw/source/core/inc/cellfrm.hxx
+++ b/sw/source/core/inc/cellfrm.hxx
@@ -24,25 +24,25 @@
#include "layfrm.hxx"
class SwTableBox;
-struct SwCrsrMoveState;
+struct SwCursorMoveState;
class SwBorderAttrs;
-/// SwCellFrm is one table cell in the document layout.
-class SwCellFrm: public SwLayoutFrm
+/// SwCellFrame is one table cell in the document layout.
+class SwCellFrame: public SwLayoutFrame
{
const SwTableBox* m_pTabBox;
virtual void DestroyImpl() override;
- virtual ~SwCellFrm();
+ virtual ~SwCellFrame();
protected:
virtual void Format( vcl::RenderContext* pRenderContext, const SwBorderAttrs *pAttrs = nullptr ) override;
virtual void Modify( const SfxPoolItem*, const SfxPoolItem* ) override;
public:
- SwCellFrm( const SwTableBox &, SwFrm*, bool bInsertContent = true );
+ SwCellFrame( const SwTableBox &, SwFrame*, bool bInsertContent = true );
- virtual bool GetCrsrOfst( SwPosition *, Point&, SwCrsrMoveState* = nullptr, bool bTestBackground = false ) const override;
+ virtual bool GetCursorOfst( SwPosition *, Point&, SwCursorMoveState* = nullptr, bool bTestBackground = false ) const override;
virtual void Paint( vcl::RenderContext& rRenderContext, SwRect const&,
SwPrintData const*const pPrintData = nullptr ) const override;
virtual void CheckDirection( bool bVert ) override;
@@ -53,14 +53,14 @@ public:
const SwTableBox *GetTabBox() const { return m_pTabBox; }
// used for breaking table rows:
- SwCellFrm* GetFollowCell() const;
- SwCellFrm* GetPreviousCell() const;
+ SwCellFrame* GetFollowCell() const;
+ SwCellFrame* GetPreviousCell() const;
// used for rowspan stuff:
- const SwCellFrm& FindStartEndOfRowSpanCell( bool bStart, bool bCurrentTab ) const;
+ const SwCellFrame& FindStartEndOfRowSpanCell( bool bStart, bool bCurrentTab ) const;
long GetLayoutRowSpan() const;
- DECL_FIXEDMEMPOOL_NEWDEL(SwCellFrm)
+ DECL_FIXEDMEMPOOL_NEWDEL(SwCellFrame)
};
#endif